package com.simuwang.manage.api.email;

import com.simuwang.base.common.page.TableDataInfo;
import com.simuwang.base.common.result.AjaxResult;
import com.simuwang.base.common.util.EncodeUtil;
import com.simuwang.base.pojo.vo.EmailFileInfoVO;
import com.simuwang.base.pojo.vo.EmailParseInfoVO;
import com.simuwang.base.pojo.vo.EmailTypeRuleVO;
import com.simuwang.daq.service.EmailParseApiService;
import com.simuwang.manage.api.base.BaseController;
import com.simuwang.manage.service.ParseEmailService;
import com.smppw.common.pojo.ResultVo;
import com.smppw.common.pojo.enums.TimeRange;
import com.smppw.common.pojo.enums.status.ResultCode;
import jakarta.servlet.ServletOutputStream;
import jakarta.servlet.http.HttpServletRequest;
import jakarta.servlet.http.HttpServletResponse;
import org.apache.ibatis.annotations.Param;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.List;
import java.util.Map;

/**
 * 解析详情管理
 * Author:   chenjianhua
 * Date:     2024/9/10 11:21
 * Description: ${DESCRIPTION}
 */
@RestController
@RequestMapping("/v1/parse")
public class ParseEmailController extends BaseController {

    @Autowired
    private ParseEmailService parseEmailService;

    @Autowired
    private EmailParseApiService emailParseApiService;
    /**
     * 保存邮件类型识别配置
     * @param emailTypeRuleVO
     * @return
     */
    @PostMapping("/save-email-type")
    public ResultVo saveEmailType(@RequestBody EmailTypeRuleVO emailTypeRuleVO){
        ResultVo vo = new ResultVo(ResultCode.SAVE_SUCCESS);
        try{
            parseEmailService.saveEmailType(emailTypeRuleVO);
        }catch (Exception e){
            logger.error(e.getMessage(),e);
            vo.setCode(ResultCode.SAVE_SUCCESS.getCode());
            vo.setMsg(e.getMessage());
        }
        return vo;
    }

    /**
     * 查询邮件类型识别配置
     * @param
     * @return
     */
    @GetMapping("/search-email-type")
    public ResultVo searchEmailType(){
        EmailTypeRuleVO emailTypeRuleVO = parseEmailService.searchEmailType();
        return ResultVo.ok(emailTypeRuleVO);
    }

    /**
     * 邮箱配置页面展示查询
     * @param emailTitle -邮件标题
     * @param emailType -邮件类型
     * @param parseStatus 解析状态:1-成功,2-净值缺失，3-未匹配基金，4-净值<=0,5-资产净值<=0
     * @param emailType -邮件类型
     * @param timeRange Last1Week-近一周,Last1Month-近一个月，Last3Months-近三月，LastHalfYear-近半年，Last1Year-近一年,FromSetup-全部，Custom-自定义
     * @param startDate -开始时间，timeRange。Custom才有数据
     * @param endDate -结束时间，timeRange。Custom才有数据
     * @return
     */
    @GetMapping("/search-email-list")
    public TableDataInfo searchEmailList(@RequestParam(value = "emailTitle",required = false)String emailTitle,
                                         @RequestParam(value = "emailType",required = false)Integer emailType,
                                         @RequestParam(value = "parseStatus",required = false)Integer parseStatus,
                                         @RequestParam(value = "timeRange",required = false)TimeRange timeRange,
                                         @RequestParam(value = "startDate",required = false)String startDate,
                                         @RequestParam(value = "endDate",required = false)String endDate){
        List<EmailParseInfoVO> result = parseEmailService.searchEmailList(emailTitle,emailType,parseStatus,timeRange,startDate,endDate);
        return getDataTable(result);
    }

    /**
     * 详情查询
     * @param id
     * @return
     */
    @GetMapping("/{id}")
    public ResultVo searchEmail(@PathVariable("id") Integer id){
        EmailParseInfoVO result = parseEmailService.searchEmailById(id);
        return ResultVo.ok(result);
    }

    /**
     * 解析邮件数据统计
     * @param timeRange Last1Week-近一周,Last1Month-近一个月，Last3Months-近三月，LastHalfYear-近半年，Last1Year-近一年,FromSetup-全部，Custom-自定义
     * @return
     */
    @GetMapping("/search-email-count")
    public ResultVo searchEmailCount(TimeRange timeRange){
        Map<String,Integer> result = parseEmailService.searchEmailCount(timeRange);
        return ResultVo.ok(result);
    }

    /**
     * 根据fileId下载邮件附件
     * @param fileId
     * @return
     */
    @PostMapping("/download-email-file")
    public void downloadEmailFile(@RequestParam("fileId") Integer fileId, HttpServletResponse response, HttpServletRequest request){
        try {
            EmailFileInfoVO emailFileInfoVO = parseEmailService.getEmailFileById(fileId);
            FileInputStream fileInputStream = new FileInputStream(emailFileInfoVO.getFilePath());
            response.setContentType("application/octet-stream");
            response.addHeader("Content-Disposition", "attachment;filename=" + EncodeUtil.encodeUTF8(emailFileInfoVO.getFileName()));
            ServletOutputStream outputStream = response.getOutputStream();
            byte[] b = new byte[1024];
            while(fileInputStream.read(b) > 0){
                outputStream.write(b);
            }
            fileInputStream.close();
            outputStream.flush();
            outputStream.close();
        } catch (IOException e) {
            logger.error(e.getMessage(),e);
        }
    }

    /**
     * 根据邮件ID重新解析
     * @param id
     * @return
     */
    @GetMapping("/reparse/{id}")
    public ResultVo reparse(@PathVariable("id")Integer id){
        emailParseApiService.reparseEmail(id);
        return ResultVo.ok(null);
    }
}
