package com.simuwang.manage.api.fund;

import com.simuwang.base.common.page.TableDataInfo;
import com.simuwang.base.pojo.vo.FundFileInfoVO;
import com.simuwang.base.pojo.vo.FundInformationVO;
import com.simuwang.base.pojo.vo.FundReportFrequencyVO;
import com.simuwang.manage.api.base.BaseController;
import com.simuwang.manage.service.EmailFundInfoService;
import com.simuwang.manage.service.FundInformationService;
import com.simuwang.manage.service.FundReportFrequencyService;
import com.smppw.common.pojo.ResultVo;
import com.smppw.common.pojo.enums.status.ResultCode;
import org.apache.ibatis.annotations.Param;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

/**
 * 基金管理
 * Author:   chenjianhua
 * Date:     2024/9/6 15:01
 * Description: ${DESCRIPTION}
 */
@RestController
@RequestMapping("/v1/fund")
public class FundInformationController extends BaseController {

    private static final Logger logger = LoggerFactory.getLogger(FundInformationController.class);


    @Autowired
    private FundInformationService fundInformationService;

    @Autowired
    private FundReportFrequencyService fundReportFrequencyService;
    @Autowired
    private EmailFundInfoService emailFundInfoService;
    /**
     * 基金搜索输入框查询
     * @param keyword
     * @return
     */
    @RequestMapping("search-info")
    public TableDataInfo searchFundInfo(@RequestParam(value = "keyword",required = false)String keyword){
        List<Map<String,String>> result = fundInformationService.searchFundInfo(keyword);
        return getDataTable(result);
    }

    /**
     *  页面展示查询
     * @param fundId 基金ID
     * @param fundShortName 基金简称
     * @param companyShortName 公司简称
     * @param navFrequency 净值报送频率，1-日频，2-周频，3-月频，4-季频，5-半年，6-年频
     * @param assetFrequency 规模报送频率，1-日频，2-周频，3-月频，4-季频，5-半年，6-年频
     * @param startDate 净值开始时间
     * @param endDate 净值结束时间
     * @return
     */
    @RequestMapping("search-list")
    public List<FundInformationVO> searchFundInfoList(
              @RequestParam(value = "fundId",required = false)String fundId,
              @RequestParam(value = "fundShortName",required = false)String fundShortName,
              @RequestParam(value = "companyShortName",required = false)String companyShortName,
              @RequestParam(value = "navFrequency",required = false)Integer navFrequency,
              @RequestParam(value = "assetFrequency",required = false)Integer assetFrequency,
              @RequestParam(value = "startDate",required = false)Integer startDate,
              @RequestParam(value = "endDate",required = false)Integer endDate){
        List<FundInformationVO> result = fundInformationService.searchFundInfoList(fundId,fundShortName,companyShortName,navFrequency,assetFrequency,startDate,endDate);
        return result;
    }

    /**
     * 保存基金报送频率
     * @param fundReportFrequency
     * @return
     */
    @PostMapping("/save-frequency")
    public ResultVo saveFundReportFrequency(@RequestBody FundReportFrequencyVO fundReportFrequency){
        ResultVo vo = new ResultVo(ResultCode.SAVE_SUCCESS);
        try{
            fundReportFrequencyService.saveFundReportFrequency(fundReportFrequency);
        }catch (Exception e){
            vo = new ResultVo(ResultCode.SAVE_FAILED);
            logger.error(e.getMessage(),e);
        }
        return vo;
    }
    /**
     * 查询基金关联的数据文件
     * @param fundId 基金ID
     * @param fileType  文件类型，估值表转2，定期报告传3
     * @param pageNum
     * @param pageSize
     * @return
     */
    @GetMapping("/search-fund-file")
    public TableDataInfo searchFundFileInfo(@RequestParam("fundId")String fundId,@RequestParam("fileType")Integer fileType,@RequestParam(value = "pageNum",required = false)Integer pageNum,@RequestParam(value ="pageSize",required = false)Integer pageSize){
        List<FundFileInfoVO> result = emailFundInfoService.searchFundFileInfo(fundId,fileType);
        return getDataTable(result);
    }

}
