package com.simuwang.manage.service;

import com.simuwang.base.pojo.dos.SysMenuDO;
import com.simuwang.base.pojo.dos.SysRoleDO;
import com.simuwang.base.service.UserAuthService;
import com.simuwang.base.utils.TreeUtil;
import com.simuwang.manage.dto.UserInfoVO;
import com.simuwang.manage.dto.UserMenuTreeDTO;
import com.simuwang.manage.dto.UserRoleDTO;
import com.simuwang.shiro.core.ShiroUser;
import org.apache.shiro.SecurityUtils;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.stream.Collectors;

/**
 * @author wangzaijun
 * @date 2024/9/12 20:28
 * @description 系统管理服务
 */
@Service
public class SystemService {
    private final UserAuthService userAuthService;

    public SystemService(UserAuthService userAuthService) {
        this.userAuthService = userAuthService;
    }

    /**
     * 获取当前用户的权限角色信息
     *
     * @return /
     */
    public UserInfoVO getUserInfo() {
        ShiroUser shiroUser = (ShiroUser) SecurityUtils.getSubject().getPrincipal();
        Integer userId = shiroUser.getUserId();
        String username = shiroUser.getUsername();
        // 用户角色信息转换
        List<SysRoleDO> roleList = this.userAuthService.listUserRoleByUserId(userId);
        List<UserRoleDTO> roles = roleList.stream()
                .map(e -> new UserRoleDTO(e.getRoleId(), e.getRoleName(), e.getRoleKey()))
                .distinct().collect(Collectors.toList());
        // 用户权限处理
        List<SysMenuDO> menuList = this.userAuthService.listUserMenuByUserId(userId);
        List<UserMenuTreeDTO> tempList = menuList.stream().map(UserMenuTreeDTO::new).collect(Collectors.toList());
        // 菜单列表转树结构
        List<UserMenuTreeDTO> trees = TreeUtil.list2Tree(tempList, UserMenuTreeDTO::getId, UserMenuTreeDTO::getPid,
                UserMenuTreeDTO::getChildren, UserMenuTreeDTO::setChildren, 0);
        UserMenuTreeDTO root = new UserMenuTreeDTO(0, "全部菜单", trees);
        // 返回的数据结构构建
        return new UserInfoVO(userId, username, roles, root);
    }
}
